from cbutil.gitlab_api import add_pagination, get_last_commit, get_git_infos_from_api, url_encode
import os
import pytest


def test_url_encode():
    assert 'walberla%2Fwalberla' == url_encode('walberla/walberla')
    assert 'walberla%2Fwalberla' == url_encode('walberla%2Fwalberla')
    assert 'walberla%2Fwalberla%2Fwalberla' == url_encode('walberla/walberla%2Fwalberla')
    assert 123 == url_encode(123)


def test_pagination():
    base_url = "http://base.url/"
    assert add_pagination(base_url, 1) == f"{base_url}?per_page=20&page=1"
    assert add_pagination(base_url, 1, per_page=1) == f"{base_url}?per_page=1&page=1"


def get_local_infos(branch_name):
    with os.popen(f'git rev-parse origin/{branch_name}') as rev:
        expected = rev.read().strip()
    return expected


@pytest.mark.skip()
@pytest.mark.parametrize("project_id", ['ob28imeq%2Fcb-util', 976])
def test_get_last_commit(project_id):
    branch_name = 'main'
    instance_url = 'https://i10git.cs.fau.de/'
    expected = get_local_infos(branch_name)

    last_commit = get_last_commit(instance_url, project_id, branch=branch_name)
    assert last_commit['id'] == expected


@pytest.mark.skip()
@pytest.mark.parametrize("project_id", ['ob28imeq%2Fcb-util', 976])
def test_get_get_git_infos(project_id):
    branch_name = 'main'
    instance_url = 'https://i10git.cs.fau.de/'
    expected = get_local_infos(branch_name)

    git_infos = get_git_infos_from_api(instance_url, project_id)

    assert git_infos['commit'] == expected
